package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtActivityAttachmentQueryParam;
import com.xdf.creative.base.vo.dt.DtActivityAttachmentQueryVo;
import com.xdf.creative.module.entity.DtActivityAttachment;
import com.xdf.creative.module.service.DtActivityAttachmentService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 园区活动板块附件 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@RestController
@RequestMapping("/dtActivityAttachment")
@Api("园区活动板块附件 API")
public class DtActivityAttachmentController extends BaseController {

    @Autowired
    private DtActivityAttachmentService dtActivityAttachmentService;

    /**
     * 添加园区活动板块附件
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加DtActivityAttachment对象", notes = "添加园区活动板块附件", response = ApiResult.class)
    public ApiResult<Boolean> addDtActivityAttachment(@Valid @RequestBody DtActivityAttachment dtActivityAttachment) throws Exception {
        boolean flag = dtActivityAttachmentService.save(dtActivityAttachment);
        return ApiResult.result(flag);
    }

    /**
     * 修改园区活动板块附件
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改DtActivityAttachment对象", notes = "修改园区活动板块附件", response = ApiResult.class)
    public ApiResult<Boolean> updateDtActivityAttachment(@Valid @RequestBody DtActivityAttachment dtActivityAttachment) throws Exception {
        boolean flag = dtActivityAttachmentService.updateById(dtActivityAttachment);
        return ApiResult.result(flag);
    }

    /**
     * 删除园区活动板块附件
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除DtActivityAttachment对象", notes = "删除园区活动板块附件", response = ApiResult.class)
    public ApiResult<Boolean> deleteDtActivityAttachment(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = dtActivityAttachmentService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取园区活动板块附件
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取DtActivityAttachment对象详情", notes = "查看园区活动板块附件", response = DtActivityAttachmentQueryVo.class)
    public ApiResult<DtActivityAttachmentQueryVo> getDtActivityAttachment(@Valid @RequestBody IdParam idParam) throws Exception {
        DtActivityAttachmentQueryVo dtActivityAttachmentQueryVo = dtActivityAttachmentService.getDtActivityAttachmentById(idParam.getId());
        return ApiResult.ok(dtActivityAttachmentQueryVo);
    }

    /**
     * 园区活动板块附件分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtActivityAttachment分页列表", notes = "园区活动板块附件分页列表", response = DtActivityAttachmentQueryVo.class)
    public ApiResult<PageTool<DtActivityAttachmentQueryVo>> getDtActivityAttachmentPageList(@Valid @RequestBody DtActivityAttachmentQueryParam dtActivityAttachmentQueryParam) throws Exception {
        PageTool<DtActivityAttachmentQueryVo> pageList = dtActivityAttachmentService.getDtActivityAttachmentPageList(dtActivityAttachmentQueryParam);
        return ApiResult.ok(pageList);
    }

}

