package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtInfoAuditBackParam;
import com.xdf.creative.base.params.dt.DtInfoAuditQueryAuiditParam;
import com.xdf.creative.base.params.dt.DtInfoAuditQueryParam;
import com.xdf.creative.base.vo.dt.DtInfoAuditBackVo;
import com.xdf.creative.base.vo.dt.DtInfoAuditQueryVo;
import com.xdf.creative.module.entity.DtInfoAudit;
import com.xdf.creative.module.service.DtInfoAuditService;
import com.xdf.creative.support.aop.OperateLogger;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 基本信息审核表 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@RestController
@RequestMapping("/dtInfoAudit")
@Api("基本信息审核表 API")
public class DtInfoAuditController extends BaseController {

    @Autowired
    private DtInfoAuditService dtInfoAuditService;



    /**
     * 获取审核基本信息（进入企业基本信息调用接口）
     */
    @PostMapping("/getOrganizeAuditInfo")
    @ApiOperation(value = "获取审核基本信息", notes = "获取审核基本信息（进入企业基本信息调用接口）", response = ApiResult.class)
    public ApiResult getOrganizeAuditInfo() throws Exception {
        return dtInfoAuditService.getOrganizeAuditInfo();
    }
    /**
     *提交审核基本信息
     */
    @PostMapping("/submitAuditInfo")
    @ApiOperation(value = "提交审核基本信息", notes = "提交审核基本信息", response = ApiResult.class)
    public ApiResult submitAuditInfo() throws Exception {
        return dtInfoAuditService.submitAuditInfo();
    }
    /**
     * 审核基本信息
     */
    @PostMapping("/auditInfo")
    @ApiOperation(value = "修改DtInfoAudit对象", notes = "审核基本信息", response = ApiResult.class)
    @OperateLogger(name = "审核自主信息",attributeId="id",attributeName="organizeId")
    public ApiResult  auditInfo(@Valid @RequestBody DtInfoAuditQueryAuiditParam dtInfoAuditQueryAuiditParam) throws Exception {
        return dtInfoAuditService.auditInfo(dtInfoAuditQueryAuiditParam);
    }


    /**
     * 后台审核自主信息列表
     */
    @PostMapping("/getAuditPageList")
    @ApiOperation(value = "获取DtInfoAudit分页列表", notes = "基本信息审核表分页列表", response = DtInfoAuditQueryVo.class)
    public ApiResult<PageTool<DtInfoAuditBackVo>> getAuditPageList(@Valid @RequestBody DtInfoAuditBackParam dtInfoAuditBackParam) throws Exception {
        PageTool<DtInfoAuditBackVo> pageList = dtInfoAuditService.getAuditPageList(dtInfoAuditBackParam);
        return ApiResult.ok(pageList);
    }



    /**
     * 基本信息审核表分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtInfoAudit分页列表", notes = "基本信息审核表分页列表", response = DtInfoAuditQueryVo.class)
    public ApiResult<PageTool<DtInfoAuditQueryVo>> getDtInfoAuditPageList(@Valid @RequestBody DtInfoAuditQueryParam dtInfoAuditQueryParam) throws Exception {
        PageTool<DtInfoAuditQueryVo> pageList = dtInfoAuditService.getDtInfoAuditPageList(dtInfoAuditQueryParam);
        return ApiResult.ok(pageList);
    }

}

