package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtParkActivitWebParam;
import com.xdf.creative.base.params.dt.DtParkActivityAddParam;
import com.xdf.creative.base.params.dt.DtParkActivityQueryParam;
import com.xdf.creative.base.params.dt.DtParkActivityUpdateParam;
import com.xdf.creative.base.vo.dt.DtParkActivityQueryVo;
import com.xdf.creative.base.vo.dt.DtParkActivityWebVo;
import com.xdf.creative.module.entity.DtParkActivity;
import com.xdf.creative.module.service.DtParkActivityService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 园区活动 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@RestController
@RequestMapping("/dtParkActivity")
@Api("园区活动 API")
public class DtParkActivityController extends BaseController {

    @Autowired
    private DtParkActivityService dtParkActivityService;


    /**
     * 增加园区活动
     * @param dtParkActivityAddParam
     * @return
     * @throws Exception
     */
    @PostMapping("/addParkActivity")
    @ApiOperation(value = "添加DtParkActivity对象", notes = "添加园区活动", response = ApiResult.class)
    public ApiResult<Boolean> addParkActivity(@Valid @RequestBody DtParkActivityAddParam dtParkActivityAddParam) throws Exception {
        return  dtParkActivityService.addParkActivity(dtParkActivityAddParam);
    }


    /**
     * 修改园区活动
     * @param dtParkActivityUpdateParam
     * @return
     * @throws Exception
     */
    @PostMapping("/updateParkActivity")
    @ApiOperation(value = "添加DtParkActivity对象", notes = "添加园区活动", response = ApiResult.class)
    public ApiResult<Boolean> updateParkActivity(@Valid @RequestBody DtParkActivityUpdateParam dtParkActivityUpdateParam) throws Exception {
        return dtParkActivityService.updateParkActivity(dtParkActivityUpdateParam);
    }


    /**
     * 获取园区活动详情
     */
    @PostMapping("/getParkActivityInfo")
    @ApiOperation(value = "获取DtParkActivity对象详情", notes = "查看园区活动", response = DtParkActivityQueryVo.class)
    public ApiResult getParkActivityInfo(@Valid @RequestBody IdParam idParam) throws Exception {
        return dtParkActivityService.getParkActivityInfo(idParam.getId());
    }



    /**
     * 园区首页活动分页列表
     */
    @PostMapping("/getWebPageList")
    @ApiOperation(value = "获取DtParkActivity分页列表", notes = "园区活动分页列表", response = DtParkActivityWebVo.class)
    public ApiResult<PageTool<DtParkActivityWebVo>> getWebPageList(@Valid @RequestBody DtParkActivitWebParam dtParkActivitWebParam) throws Exception {
        PageTool<DtParkActivityWebVo> pageList = dtParkActivityService.getWebPageList(dtParkActivitWebParam);
        return ApiResult.ok(pageList);
    }


    /**
     * 园区活动用户发布列表
     */
    @PostMapping("/getUserPageList")
    @ApiOperation(value = "获取DtParkActivity分页列表", notes = "园区活动分页列表", response = DtParkActivityWebVo.class)
    public ApiResult<PageTool<DtParkActivityWebVo>> getUserPageList(@Valid @RequestBody DtParkActivitWebParam dtParkActivitWebParam) throws Exception {
        PageTool<DtParkActivityWebVo> pageList = dtParkActivityService.getUserPageList(dtParkActivitWebParam);
        return ApiResult.ok(pageList);
    }






    /**
     * 园区活动分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtParkActivity分页列表", notes = "园区活动分页列表", response = DtParkActivityQueryVo.class)
    public ApiResult<PageTool<DtParkActivityQueryVo>> getDtParkActivityPageList(@Valid @RequestBody DtParkActivityQueryParam dtParkActivityQueryParam) throws Exception {
        PageTool<DtParkActivityQueryVo> pageList = dtParkActivityService.getDtParkActivityPageList(dtParkActivityQueryParam);
        return ApiResult.ok(pageList);
    }

}

