package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtParkCompanyQueryParam;
import com.xdf.creative.base.vo.dt.DtParkCompanyQueryVo;
import com.xdf.creative.module.entity.DtParkCompany;
import com.xdf.creative.module.service.DtParkCompanyService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 园区企业申诉文件 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-04-20
 */
@Slf4j
@RestController
@RequestMapping("/dtParkCompany")
@Api("园区企业申诉文件 API")
public class DtParkCompanyController extends BaseController {

    @Autowired
    private DtParkCompanyService dtParkCompanyService;

    /**
     * 添加园区企业申诉文件
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加DtParkCompany对象", notes = "添加园区企业申诉文件", response = ApiResult.class)
    public ApiResult  add(@Valid @RequestBody DtParkCompany dtParkCompany) throws Exception {
        return dtParkCompanyService.add(dtParkCompany);
    }

    /**
     * 修改园区企业申诉文件
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改DtParkCompany对象", notes = "修改园区企业申诉文件", response = ApiResult.class)
    public ApiResult<Boolean> updateDtParkCompany(@Valid @RequestBody DtParkCompany dtParkCompany) throws Exception {
        boolean flag = dtParkCompanyService.updateById(dtParkCompany);
        return ApiResult.result(flag);
    }

    /**
     * 删除园区企业申诉文件
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除DtParkCompany对象", notes = "删除园区企业申诉文件", response = ApiResult.class)
    public ApiResult<Boolean> deleteDtParkCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = dtParkCompanyService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取园区企业申诉文件
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取DtParkCompany对象详情", notes = "查看园区企业申诉文件", response = DtParkCompanyQueryVo.class)
    public ApiResult<DtParkCompanyQueryVo> getDtParkCompany(@Valid @RequestBody IdParam idParam) throws Exception {
        DtParkCompanyQueryVo dtParkCompanyQueryVo = dtParkCompanyService.getDtParkCompanyById(idParam.getId());
        return ApiResult.ok(dtParkCompanyQueryVo);
    }

    /**
     * 园区企业申诉文件分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtParkCompany分页列表", notes = "园区企业申诉文件分页列表", response = DtParkCompanyQueryVo.class)
    public ApiResult<PageTool<DtParkCompanyQueryVo>> getDtParkCompanyPageList(@Valid @RequestBody DtParkCompanyQueryParam dtParkCompanyQueryParam) throws Exception {
        PageTool<DtParkCompanyQueryVo> pageList = dtParkCompanyService.getDtParkCompanyPageList(dtParkCompanyQueryParam);
        return ApiResult.ok(pageList);
    }

}

