package com.xdf.creative.module.controller;

import com.xdf.creative.base.controller.BaseController;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.dt.DtParkInfoDraftQueryParam;
import com.xdf.creative.base.params.dt.DtParkInfoDraftUpdateParam;
import com.xdf.creative.base.vo.dt.DtParkInfoDraftQueryVo;
import com.xdf.creative.module.entity.DtParkInfoDraft;
import com.xdf.creative.module.service.DtParkInfoDraftService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * <p>
 * 园区表_syr made 前端控制器
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@RestController
@RequestMapping("/dtParkInfoDraft")
@Api("园区表_syr made API")
public class DtParkInfoDraftController extends BaseController {

    @Autowired
    private DtParkInfoDraftService dtParkInfoDraftService;



    /**
     * 修改园区本地未发布信息
     */
    @PostMapping("/updateParkInfoDraf")
    @ApiOperation(value = "修改DtParkInfoDraft对象", notes = "修改园区表_syr made", response = ApiResult.class)
    public ApiResult  updateParkInfoDraf(@Valid @RequestBody DtParkInfoDraftUpdateParam dtParkInfoDraftUpdateParam) throws Exception {
        return dtParkInfoDraftService.updateParkInfoDraf(dtParkInfoDraftUpdateParam);
    }


    /**
     * 获取本地修改园区基本信息
     * @param
     * @return
     * @throws Exception
     */
    @PostMapping("/getParkDraf")
    @ApiOperation(value = "获取DtParkInfoDraft对象详情", notes = "查看园区表_syr made", response = DtParkInfoDraftQueryVo.class)
    public ApiResult getParkDraf(@Valid @RequestBody IdParam idParam) throws Exception {
        return dtParkInfoDraftService.getParkDraf(idParam.getId());
    }








    /**
     * 添加园区表_syr made
     */
    @PostMapping("/add")
    @ApiOperation(value = "添加DtParkInfoDraft对象", notes = "添加园区表_syr made", response = ApiResult.class)
    public ApiResult<Boolean> addDtParkInfoDraft(@Valid @RequestBody DtParkInfoDraft dtParkInfoDraft) throws Exception {
        boolean flag = dtParkInfoDraftService.save(dtParkInfoDraft);
        return ApiResult.result(flag);
    }

    /**
     * 修改园区表_syr made
     */
    @PostMapping("/update")
    @ApiOperation(value = "修改DtParkInfoDraft对象", notes = "修改园区表_syr made", response = ApiResult.class)
    public ApiResult<Boolean> updateDtParkInfoDraft(@Valid @RequestBody DtParkInfoDraft dtParkInfoDraft) throws Exception {
        boolean flag = dtParkInfoDraftService.updateById(dtParkInfoDraft);
        return ApiResult.result(flag);
    }

    /**
     * 删除园区表_syr made
     */
    @PostMapping("/delete")
    @ApiOperation(value = "删除DtParkInfoDraft对象", notes = "删除园区表_syr made", response = ApiResult.class)
    public ApiResult<Boolean> deleteDtParkInfoDraft(@Valid @RequestBody IdParam idParam) throws Exception {
        boolean flag = dtParkInfoDraftService.removeById(idParam.getId());
        return ApiResult.result(flag);
    }

    /**
     * 获取园区表_syr made
     */
    @PostMapping("/info")
    @ApiOperation(value = "获取DtParkInfoDraft对象详情", notes = "查看园区表_syr made", response = DtParkInfoDraftQueryVo.class)
    public ApiResult<DtParkInfoDraftQueryVo> getDtParkInfoDraft(@Valid @RequestBody IdParam idParam) throws Exception {
        DtParkInfoDraftQueryVo dtParkInfoDraftQueryVo = dtParkInfoDraftService.getDtParkInfoDraftById(idParam.getId());
        return ApiResult.ok(dtParkInfoDraftQueryVo);
    }

    /**
     * 园区表_syr made分页列表
     */
    @PostMapping("/getPageList")
    @ApiOperation(value = "获取DtParkInfoDraft分页列表", notes = "园区表_syr made分页列表", response = DtParkInfoDraftQueryVo.class)
    public ApiResult<PageTool<DtParkInfoDraftQueryVo>> getDtParkInfoDraftPageList(@Valid @RequestBody DtParkInfoDraftQueryParam dtParkInfoDraftQueryParam) throws Exception {
        PageTool<DtParkInfoDraftQueryVo> pageList = dtParkInfoDraftService.getDtParkInfoDraftPageList(dtParkInfoDraftQueryParam);
        return ApiResult.ok(pageList);
    }

}

