package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.dt.*;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.dt.DtInfoAuditBackVo;
import com.xdf.creative.base.vo.dt.DtInfoAuditQueryVo;
import com.xdf.creative.base.vo.dt.DtRegionVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.enums.dt.AuditInfoStateEnum;
import com.xdf.creative.enums.dt.DisplayTypeEnum;
import com.xdf.creative.enums.dt.InfoOperatorTypeEnum;
import com.xdf.creative.enums.dt.InfoStateTypeEnum;
import com.xdf.creative.module.entity.*;
import com.xdf.creative.module.mapper.DtInfoAuditMapper;
import com.xdf.creative.module.mapper.SysRegionMapper;
import com.xdf.creative.module.service.*;
import com.xdf.creative.support.exception.BusinessException;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 基本信息审核表 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class DtInfoAuditServiceImpl extends BaseServiceImpl<DtInfoAuditMapper, DtInfoAudit> implements DtInfoAuditService {

    @Autowired
    private DtInfoAuditMapper dtInfoAuditMapper;

    @Autowired
    private DtParkInfoDraftService dtParkInfoDraftService;

    @Autowired
    private SysOrganizeService sysOrganizeService;

    @Autowired
    private DtParkActivityService dtParkActivityService;

    @Autowired
    private SysRegionMapper sysRegionMapper;

    @Autowired
    private ParkDataTeamService parkDataTeamService;


    @Autowired
    private DtActivityAttachmentService dtActivityAttachmentService;


    /**
     * 获取企业审核信息  新建基本信息（按类型判断）
     *
     * @return
     */
    @Override
    public ApiResult getOrganizeAuditInfo() {
        DtInfoAuditQueryOrganizeIdParam dtInfoAuditQueryOrganizeIdParam = new DtInfoAuditQueryOrganizeIdParam();
        if (!OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(getOrganizeType())) {
            return ApiResult.fail("非园区账户，无权限访问！");
        }
        dtInfoAuditQueryOrganizeIdParam.setOrganizeId(getOrganizeId());
        dtInfoAuditQueryOrganizeIdParam.setAuditType(OrganizeTypeEnum.ORGANIZE_PARK.getCode());
        List<DtInfoAudit> dtInfoAuditList = this.list(new QueryWrapper<DtInfoAudit>().eq("organize_id",getOrganizeId()).eq("audit_type",OrganizeTypeEnum.ORGANIZE_PARK.getCode()).orderByDesc("submit_time"));
        DtInfoAudit dtInfoAudit = null;
       /* DtInfoAudit dtInfoAudit = this.getOne(new QueryWrapper<DtInfoAudit>().eq("organize_id",getOrganizeId()).eq("audit_type",OrganizeTypeEnum.ORGANIZE_PARK.getCode()));*/

        Map<String, Object> map = new HashMap<>();
        //如果为空就新建
        if (dtInfoAuditList.size()<=0) {
            DtInfoAudit dtInfoAuditNew = new DtInfoAudit();
            dtInfoAuditNew.setAuditState(AuditInfoStateEnum.PROJECT_ADUIT_STATE_INIT.getCode());
            dtInfoAuditNew.setAuditType(getOrganizeType());
            dtInfoAuditNew.setSubmitTime(new Date());
            dtInfoAuditNew.setOrganizeId(getOrganizeId());
            dtInfoAuditNew.setSubmitUserId(getUserId());
            dtInfoAuditNew.setInfoState(InfoStateTypeEnum.DRAFT.getCode());
            dtInfoAuditNew.setUpdateTime(new Date());
            this.saveOrUpdate(dtInfoAuditNew);
            dtInfoAudit = this.list(new QueryWrapper<DtInfoAudit>().eq("organize_id",getOrganizeId()).eq("audit_type",OrganizeTypeEnum.ORGANIZE_PARK.getCode()).orderByDesc("submit_time")).get(0);
        }
        if(null==dtInfoAudit){
            dtInfoAudit =  dtInfoAuditList.get(0);
        }
        map.put("dtInfoAudit",dtInfoAudit);
        if (OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(getOrganizeType())) {
            DtParkInfoDraft dtParkInfoDraft = dtParkInfoDraftService.getOne(new QueryWrapper<DtParkInfoDraft>().eq("organize_id", getOrganizeId()));
            if (null == dtParkInfoDraft) {
                dtParkInfoDraft = new DtParkInfoDraft();
                SysOrganize sysOrganize = sysOrganizeService.getById(getOrganizeId());
                dtParkInfoDraft.setOrganizeId(getOrganizeId());
                dtParkInfoDraft.setName(sysOrganize.getOrganizeName());
                dtParkInfoDraft.setProvinceId((long) 9);
                dtParkInfoDraft.setCityId((long) 72);
                //本地库查询
                SysRegion sysRegion = sysRegionMapper.selectById(sysOrganize.getPopedomId());
                if (null != sysRegion) {
                    DtRegionParam dtRegionParam = new DtRegionParam();
                    dtRegionParam.setName(sysRegion.getRegionName());
                    DtRegionVo dtRegionVo = sysRegionMapper.getParkRegion(dtRegionParam);
                    if (null != dtRegionVo) {
                        dtParkInfoDraft.setDistrictId(dtRegionVo.getId());
                    }
                }
                dtParkInfoDraft.setDistrictName(sysRegion.getRegionName());
                dtParkInfoDraft.setStatus(StateEnum.ENABLE.getKey());
                dtParkInfoDraft.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_INIT.getCode());
                dtParkInfoDraft.setCreateUserId(getUserId());
                dtParkInfoDraft.setCreateTime(new Date());
                dtParkInfoDraft.setUpdateTime(new Date());
                dtParkInfoDraftService.saveOrUpdate(dtParkInfoDraft);
                //添加园区基本信息
//                dtParkInfoDraft = dtParkInfoDraftService.getOne(new QueryWrapper<DtParkInfoDraft>().eq("organize_id", getOrganizeId()));
            }
//            map.put("dtParkInfo", dtParkInfoDraft);
        }
        return ApiResult.ok(map);
    }

    /**
     * 用户提交审核信息
     *
     * @return
     */
    @Override
    public ApiResult submitAuditInfo() {
        DtInfoAudit dtInfoAudit = this.getOne(new QueryWrapper<DtInfoAudit>().eq("organize_id",getOrganizeId()));
        if (null == dtInfoAudit) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!verifyUserPermission(dtInfoAudit.getSubmitUserId())) {
            return ApiResult.error(StatusCode.AUTH_UPDATE_VERIFY_ERROR);
        }
        dtInfoAudit.setInfoState(InfoStateTypeEnum.SUBMIT.getCode());
        dtInfoAudit.setAuditState(AuditInfoStateEnum.PROJECT_ADUIT_STATE_WAIT.getCode());
        dtInfoAudit.setSubmitTime(new Date());
        dtInfoAudit.setSubmitUserId(getUserId());
        dtInfoAudit.setUpdateTime(new Date());
        this.saveOrUpdate(dtInfoAudit);
        return ApiResult.ok();
    }

    /**
     * 审核基本信息
     *
     * @param dtInfoAuditQueryAuiditParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult auditInfo(DtInfoAuditQueryAuiditParam dtInfoAuditQueryAuiditParam) {
        if (null == dtInfoAuditQueryAuiditParam.getId()) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        DtInfoAudit dtInfoAudit = this.getById(dtInfoAuditQueryAuiditParam.getId());
        if (null == dtInfoAudit) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        dtInfoAudit.setAuditTime(new Date());
        dtInfoAudit.setOpinion(dtInfoAuditQueryAuiditParam.getOpinion());
        dtInfoAudit.setAuditId(getUserId());
        dtInfoAudit.setUpdateTime(new Date());

        if (AuditInfoStateEnum.PROJECT_ADUIT_STATE_PASS.getCode().equals(dtInfoAuditQueryAuiditParam.getAuditState())) {
            if (OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(dtInfoAudit.getAuditType())) {
                this.parkHandle(dtInfoAudit);
            }
            dtInfoAudit.setInfoState(InfoStateTypeEnum.SUBMIT.getCode());
            dtInfoAudit.setAuditState(AuditInfoStateEnum.PROJECT_ADUIT_STATE_PASS.getCode());
        } else if (AuditInfoStateEnum.PROJECT_ADUIT_STATE_FAILED.getCode().equals(dtInfoAuditQueryAuiditParam.getAuditState())) {
            dtInfoAudit.setInfoState(InfoStateTypeEnum.DRAFT.getCode());
            dtInfoAudit.setAuditState(AuditInfoStateEnum.PROJECT_ADUIT_STATE_FAILED.getCode());
        } else {
            return ApiResult.error(StatusCode.FORM_AUTH_UPDATE_VERIFY_ERROR);
        }
        this.saveOrUpdate(dtInfoAudit);
        return ApiResult.ok();
    }

    /**
     * 后台审核自主信息列表
     *
     * @param dtInfoAuditBackParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<DtInfoAuditBackVo> getAuditPageList(DtInfoAuditBackParam dtInfoAuditBackParam) throws Exception {
        dtInfoAuditBackParam.setRegionId(getRegionId(dtInfoAuditBackParam.getRegionId()));
        Page page = setPageParam(dtInfoAuditBackParam);
        IPage<DtInfoAuditBackVo> iPage = dtInfoAuditMapper.getAuditPageList(page, dtInfoAuditBackParam);
        return new PageTool(iPage);
    }


    /**
     * 园区信息操作 DtParkInfoDraft dtParkInfoDraft =
     *
     * @param dtInfoAudit
     * @return
     */
    @Transactional
    public DtInfoAudit parkHandle(DtInfoAudit dtInfoAudit) {
        QueryWrapper<DtParkInfoDraft> parkInfoQueryWrapper = new QueryWrapper<>();
        parkInfoQueryWrapper.eq("organize_id", dtInfoAudit.getOrganizeId());
        DtParkInfoDraft dtParkInfoDraft = dtParkInfoDraftService.getOne(parkInfoQueryWrapper);
        this.parkInfoOperate(dtParkInfoDraft);
        //操作园区信息
        QueryWrapper<DtParkActivity> parkActivityQueryWrapper = new QueryWrapper<>();
        parkActivityQueryWrapper.eq("organize_id", dtInfoAudit.getOrganizeId());
        parkActivityQueryWrapper.eq("display_type", DisplayTypeEnum.DRAFT);
        List<DtParkActivity> dtParkActivityList = dtParkActivityService.list(parkActivityQueryWrapper);
        this.parkActivityOperate(dtParkActivityList);
        //操作园区活动

        return dtInfoAudit;
    }

    /**
     * 园区基本信息
     *
     * @param dtParkInfoDraft
     * @return
     */
    public boolean parkInfoOperate(DtParkInfoDraft dtParkInfoDraft) {
        if (null == dtParkInfoDraft.getDateParkId()) {
            ParkDataTeam parkDataTeam = parkDataTeamService.getOne(new QueryWrapper<ParkDataTeam>().eq("name", dtParkInfoDraft.getName()));
            dtParkInfoDraft.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_INIT.getCode());
            dtParkInfoDraft.setUpdateTime(new Date());
            if (null == parkDataTeam) {
                parkDataTeam = new ParkDataTeam();
                BeanUtils.copyProperties(dtParkInfoDraft, parkDataTeam);
                ParkDataTeam parkDataTeamNew = parkDataTeamService.getOne(new QueryWrapper<ParkDataTeam>().eq("name", dtParkInfoDraft.getName()));
                if (null == parkDataTeamNew) {
                    throw new BusinessException("园区发布信息创建失败");
                } else {
                    dtParkInfoDraft.setDateParkId(parkDataTeamNew.getId());
                    parkDataTeamService.saveOrUpdate(parkDataTeam);
                    dtParkInfoDraftService.saveOrUpdate(dtParkInfoDraft);
                }

            } else {
                dtParkInfoDraft.setDateParkId(parkDataTeam.getId());
                BeanUtils.copyProperties(dtParkInfoDraft, parkDataTeam);
                parkDataTeamService.saveOrUpdate(parkDataTeam);
                dtParkInfoDraftService.saveOrUpdate(dtParkInfoDraft);
            }
        } else {
            if (InfoOperatorTypeEnum.INFO_OPERATOR_UPDATE.getCode().equals(dtParkInfoDraft.getOperateType())) {
                ParkDataTeam parkDataTeam = parkDataTeamService.getById(dtParkInfoDraft.getDateParkId());
                BeanUtils.copyProperties(dtParkInfoDraft, parkDataTeam);
                dtParkInfoDraft.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_INIT.getCode());
                dtParkInfoDraft.setUpdateTime(new Date());
                parkDataTeamService.saveOrUpdate(parkDataTeam);
                dtParkInfoDraftService.saveOrUpdate(dtParkInfoDraft);
            }
        }
        return true;
    }

    /**
     * 园区活动操作
     *
     * @param parkActivityListDraft
     * @return
     */

    public boolean parkActivityOperate(List<DtParkActivity> parkActivityListDraft) {
        for (DtParkActivity dtParkActivity : parkActivityListDraft) {
            if (InfoOperatorTypeEnum.INFO_OPERATOR_UPDATE.getCode()
                    .equals(dtParkActivity.getOperateType())) {

                Map<String, Object> dtParkActivityUpdateParams = new HashMap<>();
                dtParkActivityUpdateParams.put("organize_id", dtParkActivity.getOrganizeId());
                dtParkActivityUpdateParams.put("display_type", DisplayTypeEnum.PUBLISH.getCode());
                dtParkActivityUpdateParams.put("group_id", dtParkActivity.getGroupId());
                List<DtParkActivity> dtParkActivityList = dtParkActivityService.list(new QueryWrapper<DtParkActivity>().eq("organize_id", dtParkActivity.getOrganizeId()).eq("display_type", DisplayTypeEnum.PUBLISH.getCode()).eq("group_id", dtParkActivity.getGroupId()));
                for (DtParkActivity dtParkActivityPublish : dtParkActivityList
                ) {
                    //先删附件
                    dtActivityAttachmentService.remove(new QueryWrapper<DtActivityAttachment>().eq("park_activity_id", dtParkActivityPublish.getForeignId()));

                }
                dtParkActivityService.removeByMap(dtParkActivityUpdateParams);
                this.parkActivityUpdate(dtParkActivity);
            } else if (InfoOperatorTypeEnum.INFO_OPERATOR_ADD.getCode()
                    .equals(dtParkActivity.getOperateType())) {
                this.parkActivityUpdate(dtParkActivity);
            } else if (InfoOperatorTypeEnum.INFO_OPERATOR_DELETE.getCode()
                    .equals(dtParkActivity.getOperateType())) {
                Map<String, Object> dtParkActivityDeleteParams = new HashMap<>();
                dtParkActivityDeleteParams.put("organize_id", dtParkActivity.getOrganizeId());
                dtParkActivityDeleteParams.put("group_id", dtParkActivity.getGroupId());

                List<DtParkActivity> dtParkActivityList = dtParkActivityService.list(new QueryWrapper<DtParkActivity>().eq("organize_id", dtParkActivity.getOrganizeId()).eq("group_id", dtParkActivity.getGroupId()));
                for (DtParkActivity dtParkActivityPublish : dtParkActivityList
                ) {
                    //先删附件
                    dtActivityAttachmentService.remove(new QueryWrapper<DtActivityAttachment>().eq("park_activity_id", dtParkActivityPublish.getForeignId()));

                }
                dtParkActivityService.removeByMap(dtParkActivityDeleteParams);
            }
        }
        return true;
    }

    /**
     * 园区活动操作
     *
     * @param dtParkActivity
     */
    public void parkActivityUpdate(DtParkActivity dtParkActivity) {
        dtParkActivity.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_INIT.getCode());
        dtParkActivity.setUpdateTime(new Date());
        DtParkActivity dtParkActivityNew = new DtParkActivity();
        BeanUtils.copyProperties(dtParkActivity, dtParkActivityNew);
        String uuid = UUIDUtil.getUUID();
        dtParkActivityNew.setDisplayType(DisplayTypeEnum.PUBLISH.getCode());
        dtParkActivityNew.setOrganizeId(dtParkActivity.getOrganizeId());
        dtParkActivityNew.setGroupId(dtParkActivity.getGroupId());
        dtParkActivityNew.setForeignId(uuid);
        dtParkActivityNew.setId((long) 0);
        dtParkActivityService.saveOrUpdate(dtParkActivity);
        dtParkActivityService.save(dtParkActivityNew);
        List<DtActivityAttachment> dtActivityAttachmentList = dtActivityAttachmentService.list(new QueryWrapper<DtActivityAttachment>().eq("park_activity_id", dtParkActivity.getForeignId()));
        if (dtActivityAttachmentList.size() > 0) {
            for (DtActivityAttachment dtActivityAttachment : dtActivityAttachmentList) {
                dtActivityAttachment.setId((long) 0);
                dtActivityAttachment.setUploadTime(new Date());
                dtActivityAttachment.setDisplayType(DisplayTypeEnum.PUBLISH.getCode());
                dtActivityAttachment.setGroupId(dtParkActivityNew.getGroupId());
                dtActivityAttachment.setUpdateTime(new Date());
                dtActivityAttachment.setParkActivityId(uuid);
                dtActivityAttachmentService.saveOrUpdate(dtActivityAttachment);
            }
        }
    }


    @Override
    public DtInfoAuditQueryVo getDtInfoAuditById(Serializable id) throws Exception {
        return dtInfoAuditMapper.getDtInfoAuditById(id);
    }

    @Override
    public PageTool<DtInfoAuditQueryVo> getDtInfoAuditPageList(DtInfoAuditQueryParam dtInfoAuditQueryParam) throws Exception {
        Page page = setPageParam(dtInfoAuditQueryParam);
        IPage<DtInfoAuditQueryVo> iPage = dtInfoAuditMapper.getDtInfoAuditPageList(page, dtInfoAuditQueryParam);
        return new PageTool(iPage);
    }

}
