package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.dt.*;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.dt.DtParkActivityBackVo;
import com.xdf.creative.base.vo.dt.DtParkActivityInfoDetailVo;
import com.xdf.creative.base.vo.dt.DtParkActivityQueryVo;
import com.xdf.creative.base.vo.dt.DtParkActivityWebVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.enums.dt.DisplayTypeEnum;
import com.xdf.creative.enums.dt.InfoOperatorTypeEnum;
import com.xdf.creative.module.entity.DtActivityAttachment;
import com.xdf.creative.module.entity.DtParkActivity;
import com.xdf.creative.module.mapper.DtParkActivityMapper;
import com.xdf.creative.module.service.DtActivityAttachmentService;
import com.xdf.creative.module.service.DtParkActivityService;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 园区活动 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class DtParkActivityServiceImpl extends BaseServiceImpl<DtParkActivityMapper, DtParkActivity> implements DtParkActivityService {

    @Autowired
    private DtParkActivityMapper dtParkActivityMapper;
    @Autowired
    private DtActivityAttachmentService dtActivityAttachmentService;


    /**
     * 增加园区活动
     * @param dtParkActivityAddParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult addParkActivity(DtParkActivityAddParam dtParkActivityAddParam) {
        DtParkActivity dtParkActivity = new DtParkActivity();
        BeanUtils.copyProperties(dtParkActivityAddParam,dtParkActivity);
        dtParkActivity.setDisplayType(DisplayTypeEnum.DRAFT.getCode());
        dtParkActivity.setCreateUserId(getUserId());
        dtParkActivity.setOrganizeId(getOrganizeId());
        String uuid = UUIDUtil.getUUID();
        dtParkActivity.setGroupId(uuid);
        dtParkActivity.setForeignId(uuid);
        dtParkActivity.setUpdateTime(new Date());
        dtParkActivity.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_ADD.getCode());
        this.saveOrUpdate(dtParkActivity);
        if(null!=dtParkActivityAddParam.getDtActivityAttachmentList()){
            List<DtActivityAttachment> dtActivityAttachmentList = dtParkActivityAddParam.getDtActivityAttachmentList();
            if(dtActivityAttachmentList.size()>0){
                for (DtActivityAttachment dtActivityAttachment:dtActivityAttachmentList) {
                    dtActivityAttachment.setId((long)0);
                    dtActivityAttachment.setUploadTime(new Date());
                    dtActivityAttachment.setDisplayType(DisplayTypeEnum.DRAFT.getCode());
                    dtActivityAttachment.setGroupId(uuid);
                    dtActivityAttachment.setUpdateTime(new Date());
                    dtActivityAttachment.setParkActivityId(uuid);
                    dtActivityAttachmentService.saveOrUpdate(dtActivityAttachment);
                }
            }
        }
        return ApiResult.ok();
    }

    /**
     * 修改园区活动
     * @param dtParkActivityUpdateParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult updateParkActivity(DtParkActivityUpdateParam dtParkActivityUpdateParam) {
        if (!InfoOperatorTypeEnum.INFO_OPERATOR_DELETE.getCode().equals(dtParkActivityUpdateParam.getOperateType())
                && !InfoOperatorTypeEnum.INFO_OPERATOR_UPDATE.getCode().equals(dtParkActivityUpdateParam.getOperateType())) {
            return ApiResult.error(StatusCode.FORM_AUTH_UPDATE_VERIFY_ERROR);
        }
        DtParkActivity dtParkActivity = this.getById(dtParkActivityUpdateParam.getId());
        if (null == dtParkActivity) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_UPDATE_VERIFY);
        }
        if (!dtParkActivity.getDisplayType().equals(DisplayTypeEnum.DRAFT.getCode())) {
            return ApiResult.error(StatusCode.FORM_AUTH_UPDATE_VERIFY_ERROR);
        }
        if (!verifyUserPermission(dtParkActivity.getCreateUserId())) {
            return ApiResult.error(StatusCode.AUTH_UPDATE_VERIFY_ERROR);
        }
        BeanUtils.copyProperties(dtParkActivityUpdateParam, dtParkActivity);
        dtParkActivity.setUpdateTime(new Date());
        dtParkActivity.setDisplayType(DisplayTypeEnum.DRAFT.getCode());

        if(!InfoOperatorTypeEnum.INFO_OPERATOR_DELETE.getCode().equals(dtParkActivityUpdateParam.getOperateType())){
            //不传不操作
            if(null!=dtParkActivityUpdateParam.getDtActivityAttachmentList()){
                List<DtActivityAttachment> dtActivityAttachmentList = dtParkActivityUpdateParam.getDtActivityAttachmentList();
                //存在则要先删除 再操作
                dtActivityAttachmentService.remove(new QueryWrapper<DtActivityAttachment>().eq("park_activity_id",dtParkActivity.getForeignId()));
                if(dtActivityAttachmentList.size()>0){
                    for (DtActivityAttachment dtActivityAttachment:dtActivityAttachmentList) {
                        dtActivityAttachment.setId((long)0);
                        dtActivityAttachment.setUploadTime(new Date());
                        dtActivityAttachment.setDisplayType(DisplayTypeEnum.DRAFT.getCode());
                        dtActivityAttachment.setGroupId(dtParkActivity.getGroupId());
                        dtActivityAttachment.setUpdateTime(new Date());
                        dtActivityAttachment.setParkActivityId(dtParkActivity.getForeignId());
                        dtActivityAttachmentService.saveOrUpdate(dtActivityAttachment);
                    }
                }
            }
        }
        this.saveOrUpdate(dtParkActivity);
        return ApiResult.ok();
    }

    /**
     * 获取活动基本详情
     * @param id
     * @return
     */
    @Override
    public ApiResult getParkActivityInfo(Serializable id) {
        DtParkActivityInfoDetailVo dtParkActivityInfoDetailVo = new DtParkActivityInfoDetailVo();
        DtParkActivity dtParkActivity = this.getById(id);
        if(null == dtParkActivity){
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        BeanUtils.copyProperties(dtParkActivity,dtParkActivityInfoDetailVo);
        List<DtActivityAttachment>   dtActivityAttachmentList = dtActivityAttachmentService.list(new QueryWrapper<DtActivityAttachment>().eq("park_activity_id",dtParkActivity.getForeignId()));
        dtParkActivityInfoDetailVo.setDtActivityAttachmentList(dtActivityAttachmentList);
        return ApiResult.ok(dtParkActivityInfoDetailVo);
    }

    @Override
    public PageTool<DtParkActivityBackVo> getBackPageList(DtParkActivitBackParam dtParkActivitBackParam) throws Exception {
        return null;
    }


    /**
     * 首页获取活动信息
     * @param dtParkActivitWebParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<DtParkActivityWebVo> getWebPageList(DtParkActivitWebParam dtParkActivitWebParam) throws Exception {
        Page page = setPageParam(dtParkActivitWebParam);
        IPage<DtParkActivityWebVo> iPage = dtParkActivityMapper.getWebPageList(page, dtParkActivitWebParam);
        return new PageTool(iPage);
    }

    /**
     * 用户自己获取园区活动信息
     * @param dtParkActivitWebParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<DtParkActivityWebVo> getUserPageList(DtParkActivitWebParam dtParkActivitWebParam) throws Exception {
        Long organizeId =getOrganizeId();
        if(organizeId.equals(dtParkActivitWebParam.getOrganizeId())){
            dtParkActivitWebParam.setOrganizeId(getOrganizeId());
            Page page = setPageParam(dtParkActivitWebParam);
            IPage<DtParkActivityWebVo> iPage = dtParkActivityMapper.getUserPageList(page, dtParkActivitWebParam);
            return new PageTool(iPage);

        }else if(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(getOrganizeType())||OrganizeTypeEnum.ORGANIZE_CITY.getCode().equals(getOrganizeType())||
                OrganizeTypeEnum.ORGANIZE_MANAGE.getCode().equals(getOrganizeType())){
            if(null==dtParkActivitWebParam.getOrganizeId()){
                IPage<DtParkActivityWebVo> iPage =null;
                return new PageTool(iPage);
            }
            dtParkActivitWebParam.setOrganizeId(dtParkActivitWebParam.getOrganizeId());
            Page page = setPageParam(dtParkActivitWebParam);
            IPage<DtParkActivityWebVo> iPage = dtParkActivityMapper.getUserPageList(page, dtParkActivitWebParam);
            return new PageTool(iPage);
        }else{
            IPage<DtParkActivityWebVo> iPage =null;
            return new PageTool(iPage);
        }
    }




    @Override
    public DtParkActivityQueryVo getDtParkActivityById(Serializable id) throws Exception {
        return dtParkActivityMapper.getDtParkActivityById(id);
    }

    @Override
    public PageTool<DtParkActivityQueryVo> getDtParkActivityPageList(DtParkActivityQueryParam dtParkActivityQueryParam) throws Exception {
        Page page = setPageParam(dtParkActivityQueryParam);
        IPage<DtParkActivityQueryVo> iPage = dtParkActivityMapper.getDtParkActivityPageList(page, dtParkActivityQueryParam);
        return new PageTool(iPage);
    }

}
