package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.dt.DtParkInfoDraftQueryParam;
import com.xdf.creative.base.params.dt.DtParkInfoDraftUpdateParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.dt.DtParkInfoDraftQueryVo;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.enums.dt.InfoOperatorTypeEnum;
import com.xdf.creative.module.entity.DtParkInfoDraft;
import com.xdf.creative.module.mapper.DtParkInfoDraftMapper;
import com.xdf.creative.module.service.DtParkInfoDraftService;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;


/**
 * <p>
 * 园区表_syr made 服务实现类
 * </p>
 *
 * @author lgw
 * @since 2020-04-09
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class DtParkInfoDraftServiceImpl extends BaseServiceImpl<DtParkInfoDraftMapper, DtParkInfoDraft> implements DtParkInfoDraftService {

    @Autowired
    private DtParkInfoDraftMapper dtParkInfoDraftMapper;

    @Override
    public ApiResult updateParkInfoDraf(DtParkInfoDraftUpdateParam dtParkInfoDraftUpdateParam) throws Exception {
        DtParkInfoDraft dtParkInfoDraft = this.getById(dtParkInfoDraftUpdateParam.getId());
        if(null==dtParkInfoDraft){
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if(null== dtParkInfoDraft.getCreateUserId()) {
            dtParkInfoDraft.setCreateUserId(getUserId());
            if (!verifyOrganizePermission(dtParkInfoDraft.getOrganizeId())) {
                return ApiResult.error(StatusCode.AUTH_UPDATE_VERIFY_ERROR);
            }
        }else{
            if (!verifyUserPermission(dtParkInfoDraft.getCreateUserId())) {
                return ApiResult.error(StatusCode.AUTH_UPDATE_VERIFY_ERROR);
            }
        }
        BeanUtils.copyProperties(dtParkInfoDraftUpdateParam,dtParkInfoDraft);
        dtParkInfoDraft.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_UPDATE.getCode());
        dtParkInfoDraft.setUpdateTime(new Date());
        if(null== dtParkInfoDraft.getCreateUserId()){
            dtParkInfoDraft.setCreateUserId(getUserId());
        }
        this.saveOrUpdate(dtParkInfoDraft);
        return ApiResult.ok();
    }

    /**
     * 获取修改详情
     * @param
     * @return
     * @throws Exception
     */
    @Override
    public ApiResult getParkDraf(Long companyId) throws Exception {
        Long organizeId =getOrganizeId();
        if(!organizeId.equals(companyId)&& !OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(getOrganizeType())&&!OrganizeTypeEnum.ORGANIZE_CITY.getCode().equals(getOrganizeType())&&
        !OrganizeTypeEnum.ORGANIZE_MANAGE.getCode().equals(getOrganizeType())){
            return ApiResult.fail("非法获取数据！");
        }

        if(!organizeId.equals(companyId)){
            organizeId = companyId;
        }
        return ApiResult.ok(dtParkInfoDraftMapper.getParkDraf(organizeId));
    }

    @Override
    public DtParkInfoDraftQueryVo getDtParkInfoDraftById(Serializable id) throws Exception {
        return dtParkInfoDraftMapper.getDtParkInfoDraftById(id);
    }

    @Override
    public PageTool<DtParkInfoDraftQueryVo> getDtParkInfoDraftPageList(DtParkInfoDraftQueryParam dtParkInfoDraftQueryParam) throws Exception {
        Page page = setPageParam(dtParkInfoDraftQueryParam);
        IPage<DtParkInfoDraftQueryVo> iPage = dtParkInfoDraftMapper.getDtParkInfoDraftPageList(page, dtParkInfoDraftQueryParam);
        return new PageTool(iPage);
    }

}
