package com.xdf.creative.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xdf.creative.base.params.IdParam;
import com.xdf.creative.base.params.creative.*;
import com.xdf.creative.base.params.dt.DtRegionParam;
import com.xdf.creative.base.service.impl.BaseServiceImpl;
import com.xdf.creative.base.vo.creative.SysOrganizeBackVo;
import com.xdf.creative.base.vo.creative.SysOrganizeQueryVo;
import com.xdf.creative.base.vo.dt.DtRegionVo;
import com.xdf.creative.constant.CommonConstant;
import com.xdf.creative.enums.OrganizeTypeEnum;
import com.xdf.creative.enums.StateEnum;
import com.xdf.creative.enums.StatusCode;
import com.xdf.creative.enums.dt.InfoOperatorTypeEnum;
import com.xdf.creative.module.entity.*;
import com.xdf.creative.module.mapper.SysOrganizeMapper;
import com.xdf.creative.module.mapper.SysRegionMapper;
import com.xdf.creative.module.service.*;
import com.xdf.creative.support.exception.BusinessException;
import com.xdf.creative.util.BeanUtil;
import com.xdf.creative.util.PasswordUtil;
import com.xdf.creative.util.StringUtil;
import com.xdf.creative.util.UUIDUtil;
import com.xdf.creative.util.page.ApiResult;
import com.xdf.creative.util.page.PageTool;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.Serializable;
import java.util.Date;
import java.util.List;


/**
 * <p>
 * 组织信息 服务实现类
 * </p>
 *
 * @author DeanYe
 * @since 2019-11-05
 */
@Slf4j
@Service
@Transactional(rollbackFor = Exception.class)
public class SysOrganizeServiceImpl extends BaseServiceImpl<SysOrganizeMapper, SysOrganize> implements SysOrganizeService {

    @Autowired
    private SysOrganizeMapper sysOrganizeMapper;
    @Autowired
    private SysRegionMapper sysRegionMapper;

    @Autowired
    private SysRegionService sysRegionService;

    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private SysUserRoleService sysUserRoleService;

    @Autowired
    private ParkDataTeamService parkDataTeamService;

    @Autowired
    private DtInfoAuditService dtInfoAuditService;

    @Autowired
    private  DtParkInfoDraftService dtParkInfoDraftService;



    /**
     * 添加园区组织
     *
     * @param sysOrganizeAddParkParam
     * @return
     */
    @Override
    @Transactional
    public ApiResult addPark(SysOrganizeAddParkParam sysOrganizeAddParkParam)  throws Exception{
        /**
         * 1 新建组织 2新建用户 3初始化 园区信息 审核信息
         */
        SysOrganize sysOrganize = new SysOrganize();
        if (StateEnum.ENABLE.getKey().equals(sysOrganizeAddParkParam.getIsCreateUser())
        ) {
            //新建用户判断用户名密码 是否为空
            if (StringUtil.isEmpty(sysOrganizeAddParkParam.getUsername()) || StringUtil.isEmpty(sysOrganizeAddParkParam.getPassword())) {
                return ApiResult.fail("用户名密码不能为空！");
            }
        }

        SysRegion sysRegion = sysRegionService.getById(sysOrganizeAddParkParam.getPopedomId());
        if (null == sysRegion) {
            return ApiResult.fail("所选行政区域不存在！");
        }
        if (this.count(new QueryWrapper<SysOrganize>().eq("organize_name", sysOrganizeAddParkParam.getOrganizeName())) > 0) {
            return ApiResult.fail("当前组织名已经存在！");
        }

        sysOrganize.setOrganizeName(sysOrganizeAddParkParam.getOrganizeName()).setCreateUserId(getUserId()).setPopedomId(sysRegion.getId()).setState(StateEnum.ENABLE.getKey()).setSystemCreate(StateEnum.DISABLE.getKey()).setOrganizeType(OrganizeTypeEnum.ORGANIZE_PARK.getCode());
        sysOrganize.setUpdateTime(new Date());

        this.saveOrUpdate(sysOrganize);

        SysOrganize sysOrganizeNew = this.getOne(new QueryWrapper<SysOrganize>().eq("organize_name", sysOrganizeAddParkParam.getOrganizeName()));
        if(null==sysOrganizeNew){
            return ApiResult.fail("园区添加失败,请重新再试！");
        }
        if (StateEnum.ENABLE.getKey().equals(sysOrganizeAddParkParam.getIsCreateUser())
        ) {
            boolean isExists = sysUserService.isExistsByUsername(sysOrganizeAddParkParam.getUsername());
            if (isExists) {
                throw new BusinessException(101001, "当前用户名已存在！");
                // return ApiResult.error(StatusCode.SYS_USER_NAME_EXIST);
            }

            SysUser sysUser = new SysUser();
            BeanUtils.copyProperties(sysOrganizeAddParkParam, sysUser);
            if(StringUtil.isEmpty(sysUser.getNickname())){
                sysUser.setNickname(sysOrganize.getOrganizeName());
            }
            String salt = UUIDUtil.getUUID();
            sysUser.setSalt(salt).setCreateUserId(getUserId()).setUserType(OrganizeTypeEnum.ORGANIZE_PARK.getCode())
                    .setDeleted(StateEnum.DISABLE.getKey()).setCreateUserId(getUserId()).setOrganizeId(sysOrganize.getId());
            // 密码加密
            String newPassword = PasswordUtil.encrypt(sysUser.getPassword(), salt);
            sysUser.setPassword(newPassword);
            sysUser.setState(StateEnum.ENABLE.getKey());
            sysUserService.saveOrUpdate(sysUser);

            //添加角色
            SysUser sysUserNew = sysUserService.getSysUserByUserName(sysUser.getUsername());
            SysUserRole sysUserRole = new SysUserRole();
            sysUserRole.setUserId(sysUserNew.getId()).setRoleId((long) 3);
            sysUserRoleService.saveOrUpdate(sysUserRole);

        }
        //初始化基本信息
        DtParkInfoDraft dtParkInfoDraft = new DtParkInfoDraft();
        dtParkInfoDraft.setOrganizeId(sysOrganizeNew.getId());
        dtParkInfoDraft.setName(sysOrganizeNew.getOrganizeName());
        dtParkInfoDraft.setProvinceId((long)9);
        dtParkInfoDraft.setCityId((long)72);
        //本地库查询
        if(null!=sysRegion){
            DtRegionParam dtRegionParam = new DtRegionParam();
            dtRegionParam.setName(sysRegion.getRegionName());
            DtRegionVo dtRegionVo = sysRegionMapper.getParkRegion(dtRegionParam);
            if(null!=dtRegionVo){
                dtParkInfoDraft.setDistrictId(dtRegionVo.getId());
            }
        }
        dtParkInfoDraft.setDistrictName(sysRegion.getRegionName());
        dtParkInfoDraft.setStatus(StateEnum.DISABLE.getKey());
        dtParkInfoDraft.setOperateType(InfoOperatorTypeEnum.INFO_OPERATOR_INIT.getCode());
        dtParkInfoDraft.setCreateTime(new Date());
        dtParkInfoDraft.setAddress(sysOrganizeAddParkParam.getAddress());
        dtParkInfoDraft.setContactor(sysOrganizeAddParkParam.getContactor());
        dtParkInfoDraft.setCntComCult(sysOrganizeAddParkParam.getCntComCult());
        dtParkInfoDraft.setCntComJoin(sysOrganizeAddParkParam.getCntComJoin());
        dtParkInfoDraft.setParentCom(sysOrganizeAddParkParam.getParentCom());
        dtParkInfoDraft.setPhone(sysOrganizeAddParkParam.getPhone());
        dtParkInfoDraft.setUpdateTime(new Date());
        dtParkInfoDraftService.saveOrUpdate(dtParkInfoDraft);
        return ApiResult.ok();
    }

    /**
     * 添加组织机构
     *
     * @param sysOrganizeAddParam
     * @return
     */
    @Override
    public ApiResult add(SysOrganizeAddParam sysOrganizeAddParam)  throws Exception{
        //1检查企业名是否存在
        if (this.count(new QueryWrapper<SysOrganize>().eq("organize_name", sysOrganizeAddParam.getOrganizeName())) > 0) {
            return ApiResult.fail("当前组织名已经存在！");
        }

        SysRegion sysRegion = sysRegionService.getById(sysOrganizeAddParam.getPopedomId());
        if (null == sysRegion) {
            return ApiResult.fail("所选行政区域不存在！");
        }
        SysOrganize sysOrganize = new SysOrganize();
        sysOrganize.setCreateUserId(getUserId());
        BeanUtils.copyProperties(sysOrganizeAddParam, sysOrganize);
        if (OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(sysOrganizeAddParam.getOrganizeType()) ||
                OrganizeTypeEnum.ORGANIZE_CITY.getCode().equals(sysOrganizeAddParam.getOrganizeType())) {
            SysOrganize sysOrganizeNew = this.getById(sysOrganizeAddParam.getParentId());
            if (null == sysOrganizeNew || (!sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_CITY.getCode()) && !sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode()))) {
                return ApiResult.fail("上级机构未选择！");
            }
            sysOrganize.setParentId(sysOrganizeAddParam.getParentId());
        } else if (OrganizeTypeEnum.ORGANIZE_PARK.getCode().equals(sysOrganizeAddParam.getOrganizeType())) {
            sysOrganize.setParentId(null);
        } else {
            return ApiResult.fail("未选择正确的账户类型！");
        }
        sysOrganize.setPopedomId(sysRegion.getId()).setState(StateEnum.ENABLE.getKey()).setSystemCreate(StateEnum.DISABLE.getKey());
        this.saveOrUpdate(sysOrganize);
        return ApiResult.ok();
    }

    /**
     * 修改文创办组织信息
     *
     * @param sysOrganizeEditParam
     * @return
     */
    @Override
    public ApiResult editMange(SysOrganizeEditParam sysOrganizeEditParam)  throws Exception{
        SysOrganize sysOrganize = this.getById(sysOrganizeEditParam.getId());
        if (null == sysOrganize) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null != sysOrganizeEditParam.getPopedomId() && sysOrganizeEditParam.getPopedomId() != sysOrganize.getPopedomId()) {
            SysRegion sysRegion = sysRegionService.getById(sysOrganizeEditParam.getPopedomId());
            if (null == sysRegion) {
                return ApiResult.fail("所选行政区域不存在！");
            }
            sysOrganize.setPopedomId(sysRegion.getId());
        }
        if (null != sysOrganizeEditParam.getParentId() && sysOrganizeEditParam.getParentId() != sysOrganize.getParentId()) {
            SysOrganize sysOrganizeNew = this.getById(sysOrganizeEditParam.getParentId());
            if (null == sysOrganizeNew || (!sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_CITY.getCode()) && !sysOrganizeNew.getOrganizeType().equals(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode()))) {
                return ApiResult.fail("上级机构未选择！");
            }
            sysOrganize.setParentId(sysOrganizeNew.getParentId());
        }
        sysOrganize.setOrganizeName(sysOrganizeEditParam.getOrganizeName());
        sysOrganize.setUpdateTime(new Date());
        this.saveOrUpdate(sysOrganize);
        return ApiResult.ok();
    }

    /**
     * 修改园区组织信息
     *
     * @param sysOrganizeEditParam
     * @return
     */
    @Override
    public ApiResult editPark(SysOrganizeEditParam sysOrganizeEditParam)  throws Exception{
        SysOrganize sysOrganize = this.getById(sysOrganizeEditParam.getId());
        if (null == sysOrganize) {
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }
        if (null != sysOrganizeEditParam.getPopedomId() && sysOrganizeEditParam.getPopedomId() != sysOrganize.getPopedomId()) {
            SysRegion sysRegion = sysRegionService.getById(sysOrganizeEditParam.getPopedomId());
            if (null == sysRegion) {
                return ApiResult.fail("所选行政区域不存在！");
            }
            sysOrganize.setPopedomId(sysRegion.getId());
        }
        sysOrganize.setOrganizeName(sysOrganizeEditParam.getOrganizeName());
        sysOrganize.setUpdateTime(new Date());
        this.saveOrUpdate(sysOrganize);
        return ApiResult.ok();
    }


    @Override
    public ApiResult enabledOrganize(IdParam idParam) {
        if(null == idParam){
            return ApiResult.fail("未选择组织");
        }
        SysOrganize sysOrganize = this.getById(idParam.getId());
        if(null==sysOrganize){
            return ApiResult.error(StatusCode.FORM_SUBMIT_ID_VERIFY);
        }

        if(sysOrganize.getState().equals(StateEnum.ENABLE.getKey())){
            sysOrganize.setState(StateEnum.DISABLE.getKey());
        }else{
            sysOrganize.setState(StateEnum.ENABLE.getKey());
        }
        this.saveOrUpdate(sysOrganize);

        return ApiResult.ok();
    }


    /**
     * 获取组织机构资源数
     *
     * @return
     * @throws Exception
     */
    @Override
    public List<Object> getOrganizeTreeList() throws Exception {

        return baseMapper.getTreeOrganizeList(getRegionId(""));
    }

    @Override
    public String getRootOrganizeId() throws Exception {
        if(OrganizeTypeEnum.ORGANIZE_DISTRICT.getCode().equals(getOrganizeType())){
            return "3";
        }else{
            return "1";
        }
    }


    @Override
    public SysOrganizeQueryVo getSysOrganizeById(Serializable id) throws Exception {
        return sysOrganizeMapper.getSysOrganizeById(id);
    }

    /**
     * 后台获取文创办组织
     *
     * @param sysOrganizeBackParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<SysOrganizeBackVo> getManagePageList(SysOrganizeBackParam sysOrganizeBackParam) throws Exception {
        String regionId = getRegionId(sysOrganizeBackParam.getRegionId());
        sysOrganizeBackParam.setRegionId(regionId);
        Page page = setPageParam(sysOrganizeBackParam);
        IPage<SysOrganizeBackVo> iPage = sysOrganizeMapper.getManagePageList(page, sysOrganizeBackParam);
        return new PageTool(iPage);
    }


    /**
     * 后台获取园区组织
     *
     * @param sysOrganizeBackParam
     * @return
     * @throws Exception
     */
    @Override
    public PageTool<SysOrganizeBackVo> getParkPageList(SysOrganizeBackParam sysOrganizeBackParam) throws Exception {
        String regionId = getRegionId(sysOrganizeBackParam.getRegionId());
        sysOrganizeBackParam.setRegionId(regionId);
        Page page = setPageParam(sysOrganizeBackParam);
        IPage<SysOrganizeBackVo> iPage = sysOrganizeMapper.getParkPageList(page, sysOrganizeBackParam);
        return new PageTool(iPage);
    }


    @Override
    public PageTool<SysOrganizeQueryVo> getSysOrganizePageList(SysOrganizeQueryParam sysOrganizeQueryParam) throws Exception {
        Page page = setPageParam(sysOrganizeQueryParam);
        IPage<SysOrganizeQueryVo> iPage = sysOrganizeMapper.getSysOrganizePageList(page, sysOrganizeQueryParam);
        return new PageTool(iPage);
    }


    @Override
    public boolean isEnableSysOrganize(IsEnableSysOrganizeParam isEnableSysOrganizeParam) throws Exception {
        Integer count = sysOrganizeMapper.isEnableSysOrganize(isEnableSysOrganizeParam);
        return count > 0;
    }


}
